<?php
namespace Eyepin\Eyepin6\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2014 Ingrid Stürmer <i.stuermer@chilischarf.at>, chiliSCHARF Kommunikationsagentur e.U.
 *  
 ***************************************************************/

/**
 * @package eyepin6
 */
class EyepinController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {

	/**
	 * eyepinRepository
	 *
	 * @var \Eyepin\Eyepin6\Domain\Repository\EyepinRepository
	 * @inject
	 */
	protected $eyepinRepository;
	
	public function initializeAction() {
 
        if(TYPO3_MODE === 'BE') {
 
            $configurationManager = $this->objectManager->get('Tx_Extbase_Configuration_BackendConfigurationManager');
            $this->settings = $configurationManager->getConfiguration(
                $this->request->getControllerExtensionName(),
                $this->request->getPluginName()
            );            
 
        }
 
    }
	
	
	/**
	 * action newslist
	 * newslist for backend module
	 * 
	 * @return void
	 */
	public function newslistAction() {
		
		$arrayOptions = array();
		
		$news = $this->eyepinRepository->findAllNews();
		
		if($this->request->hasArgument('newsFilter')){
			
			if($this->request->getArgument('newsFilter') == "all_exported"){
				$news = $this->eyepinRepository->findAllExportedNews();
				
				$arrayOptions['all_exported'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('be_all_exported', 'eyepin6');
				$arrayOptions['all'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('be_all', 'eyepin6');
				$arrayOptions['all_non_exported'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('be_all_not_exported', 'eyepin6');
			}
			else if($this->request->getArgument('newsFilter') == "all_non_exported"){
				$news = $this->eyepinRepository->findAllNonExportedNews();
				
				$arrayOptions['all_non_exported'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('be_all_not_exported', 'eyepin6');
				$arrayOptions['all_exported'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('be_all_exported', 'eyepin6');
				$arrayOptions['all'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('be_all', 'eyepin6');	
			}
			else{
				$arrayOptions['all'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('be_all', 'eyepin6');
				$arrayOptions['all_exported'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('be_all_exported', 'eyepin6');
				$arrayOptions['all_non_exported'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('be_all_not_exported', 'eyepin6');
			}
			
		}
		else{
			$arrayOptions['all'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('be_all', 'eyepin6');
			$arrayOptions['all_exported'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('be_all_exported', 'eyepin6');
			$arrayOptions['all_non_exported'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('be_all_not_exported', 'eyepin6');
		}
	
		$this->view->assign('news', $news);
		$this->view->assign('arrayOptions', $arrayOptions);
				
	}
	
	
	/**
	 * action process
	 * 
	 * process action for backend module
	 *
	 * @return void
	 */
	public function processAction() {
		
		$newsArray = array();
		
		//run through arguments and get news ids
		foreach($this->request->getArguments() as $key => $value){
			
			if(strpos($key, 'news') !== false){
				$newsArray = $value;
			}		
			
		}
		
		$this->view->assign('news', $newsArray);
		
		if($this->request->hasArgument('cmd') && $this->request->hasArgument('articleId')){
			
			if(strlen($this->request->getArgument('cmd')) > 0 && $this->request->getArgument('articleId') > 0){

				switch ($this->request->getArgument('cmd')) {
		
					case 'export':
		
						$articles = array();
						$articles[0] = $this->request->getArgument('articleId');
						$this->exportArticles($articles);
		
						break;
		
					case 'update':
		
						$articles = array();
						$articles[0] = $this->request->getArgument('articleId');
						$this->updateArticles($articles);
		
						break;
		
					case 'delete':
			
						$articles = array();
						$articles[0] = $this->request->getArgument('articleId');
						$this->deleteArticles($articles);
		
						break;
		
				}
			}
			
		}
		
		if($this->request->hasArgument('submit_export')){
			$this->exportArticles($newsArray);
		}
		else if($this->request->hasArgument('submit_update')){
			$this->updateArticles($newsArray);
		}
		else if($this->request->hasArgument('submit_delete')){
			$this->deleteArticles($newsArray);
		}
		
		$this->forward('newslist', 'Eyepin', 'eyepin6', NULL);
	}

	/**
	 * action export
	 * export selected articles to eyepin system
	 * 
	 * @param array $articles
	 */
	public function exportArticles($articles){
		
		$eyepinConnection = $this->objectManager->get('Eyepin\\Eyepin6\\Utility\\Connect');
		
		$this->eyepinConf = $this->settings['settings'];
		
		$eyepinConnection->setHost($this->eyepinConf['eyepinHost']);
		$eyepinConnection->setUsername($this->eyepinConf['eyepinUser']);
		$eyepinConnection->setPassword($this->eyepinConf['eyepinPassword']);
		
		$customerId = $this->eyepinConf['mandant'];	

		$i = 0;
		
		foreach ($articles as $article) {

			// get news article data
			
			$row = $this->eyepinRepository->findArticleById($article);
			
			if($row){
				
				$data = $this->createData($row[0]);

				//sign in
				$connectionResult = $eyepinConnection->sendCommand('ContentInsert', $customerId, $data);	
				
				if ($connectionResult == EYEPIN_CON_SUCCESS) {

					$response = $eyepinConnection->getResponse();
					
					$eyepinId = intval($response->data[0]);
					
					$newsItem = new \Eyepin\Eyepin6\Domain\Model\Eyepin;
					$newsItem->setEyepinid($eyepinId);
					$newsItem->setNewsid(intval($article));
					
					$this->eyepinRepository->add($newsItem);
					
					$newsItems[$i] = $newsItem;
					$i++;
					
				}
				
			}

		}
		
	}
	
	/**
	* update articles
	* 
	* update selected articles in eyepin system
	* 
	* @param array $articles
	*/
	public function updateArticles($articles){
		
		$eyepinConnection = $this->objectManager->get('Eyepin\\Eyepin6\\Utility\\Connect');
		
		$this->eyepinConf = $this->settings['settings'];
		
		$eyepinConnection->setHost($this->eyepinConf['eyepinHost']);
		$eyepinConnection->setUsername($this->eyepinConf['eyepinUser']);
		$eyepinConnection->setPassword($this->eyepinConf['eyepinPassword']);
		
		$customerId = $this->eyepinConf['mandant'];		

		foreach ($articles as $article) {

			// get news article data

			$rowNews = $this->eyepinRepository->findArticleById($article);
		
			$rowEyepinNews = $this->eyepinRepository->findByNewsId($article);
			
			if($rowNews){

				$data = $this->createData($rowNews[0]);
				$data['id'] = $rowEyepinNews[0]['eyepinid'];
				
				//sign in
				$connectionResult = $eyepinConnection->sendCommand('ContentUpdate', $customerId, $data);	
	
				if ($connectionResult == EYEPIN_CON_SUCCESS) {

					$response = $eyepinConnection->getResponse();
										
				}
			}
			
		}
		
	}
	
	/**
	 * delete articles
	 * 
	 * delete selected articles in eyepin system
	 * 
	 * @param array $articles
	 */
	public function deleteArticles($articles){
		
		$eyepinConnection = $this->objectManager->get('Eyepin\\Eyepin6\\Utility\\Connect');
		
		$this->eyepinConf = $this->settings['settings'];
		
		$eyepinConnection->setHost($this->eyepinConf['eyepinHost']);
		$eyepinConnection->setUsername($this->eyepinConf['eyepinUser']);
		$eyepinConnection->setPassword($this->eyepinConf['eyepinPassword']);
		
		$customerId = $this->eyepinConf['mandant'];		

		foreach ($articles as $article) {

			// get news article data

			$rowNews = $this->eyepinRepository->findArticleById($article);
		
			$rowEyepinNews = $this->eyepinRepository->findByNewsId($article);
			
			if($rowNews){

				$data = array();
				$data['id'] = $rowEyepinNews[0]['eyepinid'];
				
				//sign in
				$connectionResult = $eyepinConnection->sendCommand('ContentDelete', $customerId, $data);	
	
				if ($connectionResult == EYEPIN_CON_SUCCESS) {

					$response = $eyepinConnection->getResponse();
										
					$this->eyepinRepository->deleteArticle($article);
	
				}
			}
			
		}
				
	}
	
	/**
	 * Create data array for Eyepin interface.
	 *
	 * @param array $row  The data of a tt_news article
	 * @return array  The data ready to transmit to Eyepin server via the interface.
	 */

	function createData($row) {

		$data = array();

		$data['id'] = $row['eyepinid'];
		$data['title'] = $row['title'];
		$data['opener'] = $row['teaser'];
		$data['detail'] = $row['bodytext'];
		
		$rowMedia = $this->eyepinRepository->findArticleMediaById($row['media']);
		
		if($rowMedia[0]['image']){
			$data['pictureurl'] = "http://" . $_SERVER['HTTP_HOST'] . "/uploads/tx_news/" . $rowMedia[0]['image'];
		}
		else{
			$data['pictureurl'] = "";
		}
		
		$data['detailurl'] = "";
		
		return $data;

	}
	

	/**
	 * action form
	 * 
	 * form for frontend newsletter registration
	 *
	 * @return void
	 */
	public function formAction() {
		
		$requiredFields = explode(",", $this->settings['requiredFields']);
		
		$errorCount = 0;
		
		if(count($this->request->getArguments()) > 0){
		
			if($this -> request -> getArgument('submit')){
			
				for($i = 0; $i < count($requiredFields); $i++){
					
					if(trim($requiredFields[$i]) != ""){
					
						if($this -> request -> getArgument(trim($requiredFields[$i])) == ""){
							
							$this->view->assign('error_messages', \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('text_fill_in_inputs', $this->extensionName));

							$errorCount++;
						}

					}
	
				}
				
				if($errorCount == 0){
					$this->redirect('subscribe', 'Eyepin', 'eyepin6', $this -> request -> getArguments() );
				}
				
				foreach($this->request->getArguments() as $key => $value){
					$this->view->assign($key, $value);
				}
				
			}
			
		}
		
		$salutationArray['0'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('label_salutation_choose', $this->extensionName);
		$salutationArray['Frau'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('label_salutation_mrs', $this->extensionName);
		$salutationArray['Herr'] = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('label_salutation_mr', $this->extensionName);
		
		$this->view->assign('salutationArray', $salutationArray);
		
	}

	
	/**
	 * action subscribe
	 *
	 * @return void
	 */
	public function subscribeAction() {

		$data = array();
		
		foreach($this->settings['mapping'] as $key => $value){
			
			if($this->request->hasArgument($key)){
				$data[$value] = $this -> request -> getArgument($key);
			}
			
		}
	
		$eyepinConnection = $this->objectManager->get('Eyepin\\Eyepin6\\Utility\\Connect');
		
		$data['newsletterformat'] = 'html';
		$data['handleoptin'] = '1';
		$data['handleoptout'] = '';
		$data['status'] = '1';
		
		
		$eyepinConnection->setHost($this->settings['eyepinHost']);
		$eyepinConnection->setUsername($this->settings['eyepinUser']);
		$eyepinConnection->setPassword($this->settings['eyepinPassword']);
		
		$customerId = $this->settings['mandant'];	
		
		//sign in
		$connectionResult = $eyepinConnection->sendCommand('AddressInsert', $customerId, $data);
		
		if($connectionResult == 0){
			$this->view->assign('subscribeError', "");

			if($this->settings['redirectPage']){
				$uriBuilder = $this->controllerContext->getUriBuilder();
				$uriBuilder->reset();
				$uriBuilder->setTargetPageUid($this->settings['redirectPage']);
				$uriBuilder->setArguments(array());
				$uri = $uriBuilder->build();
				$this->redirectToUri($uri);
			} else{

				$this->view->assign('subscribeSuccess', \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('subscribeSuccess', $this->extensionName));

			}
		}
		else{
			
			$this->view->assign('subscribeError', \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('subscribeError', $this->extensionName));
			$this->view->assign('subscribeSuccess', '');
			
		}
		
		
	}
	
	/**
	 * action unsubscribeform
	 *
	 * @return void
	 */
	public function unsubscribeformAction(){
		
		$requiredFields = explode(",", $this->settings['requiredFields']);
		
		$errorCount = 0;
		
		if(count($this->request->getArguments()) > 0){
		
			if($this -> request -> hasArgument('submit')){
			
				for($i = 0; $i < count($requiredFields); $i++){

					

					if(trim($requiredFields[$i]) != ""){
						
						if($this -> request -> getArgument(trim($requiredFields[$i])) == ""){
							
							$this->view->assign('error_messages', \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('text_fill_in_inputs', $this->extensionName));
							
							$errorCount++;
						}

					}
	
				}
				
				if($errorCount == 0){
					$this->redirect('unsubscribe', 'Eyepin', 'eyepin6', $this -> request -> getArguments() );
				}
				
			}
			
		}
		
	}
	
	/**
	 * action unsubscribe
	 * Unsubscribe from newsletter
	 *
	 * @return void
	 */
	public function unsubscribeAction() {

		$data = array();
		
		$requiredFields = explode(",", $this->settings['requiredFields']);
		
		$errorCount = 0;
		
		if(count($this->request->getArguments()) > 0){
			
			if($this -> request -> getArgument('submit')){
			
				$email = $this -> request -> getArgument('email');
		
				$data['email'] = $email;
			
				$eyepinConnection = $this->objectManager->get('Eyepin\\Eyepin6\\Utility\\Connect');
				
				$eyepinConnection->setHost($this->settings['eyepinHost']);
				$eyepinConnection->setUsername($this->settings['eyepinUser']);
				$eyepinConnection->setPassword($this->settings['eyepinPassword']);
				
				$customerId = $this->settings['mandant'];	
				
				$connectionResult = $eyepinConnection->sendCommand('AddressDelete', $customerId, $data);
				
				if($connectionResult == 0){
					$this->view->assign('eyepinError', "");
					
					// redirect to unsubscribe redirect page or show success message
					if($this->settings['redirectPageUnsubscribe']){
							
						$this->redirect(NULL, NULL, NULL, NULL, $this->settings['redirectPageUnsubscribe']);
						
					} else{
							
						$this->view->assign('eyepinUnsubscribeSuccess', \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('unsubscribeSuccess', $this->extensionName));
						
					}
				}
				else{
					
					$this->view->assign('eyepinError', \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('unsubscribeEmailNotFound', $this->extensionName));
					$this->view->assign('eyepinUnsubscribeSuccess', '');
					
				}

			}
		}
	}
	
	/**
	 * Fuction called by Powermail on sending form
	 * 
	 * @param $params - email paramters 
	 * @param $obj
	 */
	public function powermailHook($params, $obj) {
		
		$data = array();
		
		//id of actual page
		$pageId = $GLOBALS['TSFE']->id;
		
		$sysPageObj = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('t3lib_pageSelect');
		$rootLine = $sysPageObj->getRootLine($pageId);
		
		//get typoscript configuration of eyepin extension
		$TSObj = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('t3lib_tsparser_ext');
		$TSObj->tt_track = 0;
		$TSObj->init();
		$TSObj->runThroughTemplates($rootLine);
		$TSObj->generateConfig();
		$this->eyepinConf = $TSObj->setup['plugin.']['tx_eyepin6.']['settings.'];
		
		//mapping form paramters - data array
    	foreach($this->eyepinConf['mapping.'] as $key => $value){
			
			if($params[$key]){
				
				if(is_array($params[$key])){
				
					$data[$value] = $params[$key][0];
				}
				else{
					$data[$value] = $params[$key];
				}
			}
			else{
				$data[$value] = "";
			}
				
		}
		
		$data['newsletterformat'] = 'html';
		$data['handleoptin'] = '1';
		$data['handleoptout'] = '';
		$data['status'] = '1';
		
		//if newsletter is selected, send subscription to eyepin
		if($data['newsletter']){
		
			//send newsletter subscription to eyepin
			
			$customerId = $this->eyepinConf['mandant'];	
			$objectManager = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('Tx_Extbase_Object_ObjectManager'); 
			
			//establish eyepin connection
			$eyepinConnection = $objectManager->get('Eyepin\\Eyepin6\\Utility\\Connect');
				
			$eyepinConnection->setHost($this->eyepinConf['eyepinHost']);
			$eyepinConnection->setUsername($this->eyepinConf['eyepinUser']);
			$eyepinConnection->setPassword($this->eyepinConf['eyepinPassword']);
	
			//send subscription to eyepin
			$connectionResult = $eyepinConnection->sendCommand('AddressInsert', $customerId, $data);
	   		
		}
		
	}
	
}
?>