<?php
namespace Eyepin\Eyepin6\Domain\Repository;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2014 Ingrid Stürmer <i.stuermer@chilischarf.at>, chiliSCHARF Kommunikationsagentur e.U.
 *  
 ***************************************************************/

/**
 * @package eyepin6
 *
 */
class EyepinRepository extends \TYPO3\CMS\Extbase\Persistence\Repository {
	
	/**
	 * find all eyepin-news entries (tt_news or tx_news)
	 * 
	 * @return result - array of news
	 */
	public function findAll(){
		
		$query = $this->createQuery();
		
		$result = $query->execute();

		return $result;
	}
	
	/**
	 * find a news article by id (tt_news or tx_news)
	 * 
	 * @param string $newsId
	 * @return result - array of news
	 */
	public function findByNewsId($newsId){
		$query = $this -> createQuery();
		$query->getQuerySettings()->setReturnRawQueryResult(TRUE);
		
		$query->statement('SELECT uid, eyepinid, newsid FROM tx_eyepin6_domain_model_eyepin WHERE newsid=' . $newsId . ' ORDER by uid DESC LIMIT 1');
		
		$result = $query->execute();
		
		return $result;
	}
	
	/**
	 * find all news articles (tt_news or tx_news)
	 * 
	 * @return result - array of news
	 */
	public function findAllNews(){
		
		$query = $this -> createQuery();
		$query->getQuerySettings()->setReturnRawQueryResult(TRUE);
		
		if(\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::isLoaded('tt_news')){
			
			//get tt_news entries
			$query->statement('SELECT uid, title, tstamp, crdate, short as teaser, bodytext, image, imagecaption FROM tt_news WHERE hidden=0 AND deleted=0');
			$result = $query->execute();
		}
		else if(\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::isLoaded('news')){
			
			//if no tt_news get entries of newssystem
			if(!$result){
				$query->statement('SELECT uid, title, tstamp, crdate, teaser, bodytext FROM tx_news_domain_model_news WHERE hidden=0 AND deleted=0');
				$result = $query->execute();
			}
				
		}
		else{
			//no news
		}
		
		$newsItems = array();
		
		$i = 0;
		
		foreach($result as $news){
			
			$newsItem['uid'] = $news['uid'];
			$newsItem['title'] = $news['title'];
			$newsItem['crdate'] = $news['crdate'];
			$newsItem['tstamp'] = $news['tstamp'];
			$newsItem['teaser'] = $news['teaser'];
			$newsItem['bodytext'] = $news['bodytext'];
			$newsItem['image'] = $news['image'];
			$newsItem['imagecaption'] = $news['imagecaption'];
			
			if($this->newsInEyepin($news['uid'])){
				$newsItem['eyepin'] = 1;
			}
			else{
				$newsItem['eyepin'] = 0;
			}
			
			$newsItems[$i] = $newsItem;
			$i++;
		}
		
		return $newsItems;
	}
	
	/**
	 * find all news exported to eyepin
	 * 
	 * @return result - array of news
	 */
	public function findAllExportedNews(){
		
		$query = $this -> createQuery();
		$query->getQuerySettings()->setReturnRawQueryResult(TRUE);
		
		if(\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::isLoaded('tt_news')){
			
			//get tt_news entries
			$query->statement('SELECT uid, title, tstamp, crdate, short as teaser, bodytext, image, imagecaption FROM tt_news WHERE hidden=0 AND deleted=0');
			$result = $query->execute();
		}
		else if(\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::isLoaded('news')){
			
			//if no tt_news get entries of newssystem
			if(!$result){
				$query->statement('SELECT uid, title, tstamp, crdate, teaser, bodytext FROM tx_news_domain_model_news WHERE hidden=0 AND deleted=0');
				$result = $query->execute();
			}
				
		}
		else{
			//no news
		}
		
		$newsItems = array();
		
		$i = 0;
		
		foreach($result as $news){
			
			if($this->newsInEyepin($news['uid'])){
			
				$newsItem['uid'] = $news['uid'];
				$newsItem['title'] = $news['title'];
				$newsItem['crdate'] = $news['crdate'];
				$newsItem['tstamp'] = $news['tstamp'];
				$newsItem['teaser'] = $news['teaser'];
				$newsItem['bodytext'] = $news['bodytext'];
				$newsItem['image'] = $news['image'];
				$newsItem['imagecaption'] = $news['imagecaption'];
				
				if($this->newsInEyepin($news['uid'])){
					$newsItem['eyepin'] = 1;
				}
				else{
					$newsItem['eyepin'] = 0;
				}
				
				$newsItems[$i] = $newsItem;
				$i++;
			}
		}
		
		return $newsItems;
	}
	
	/**
	 * find all non exported news to eyepin
	 * 
	 * @return result - array of news
	 */
	public function findAllNonExportedNews(){
		
		$query = $this -> createQuery();
		$query->getQuerySettings()->setReturnRawQueryResult(TRUE);
		
		if(\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::isLoaded('tt_news')){
			
			//get tt_news entries
			$query->statement('SELECT uid, title, tstamp, crdate, short as teaser, bodytext, image, imagecaption FROM tt_news WHERE hidden=0 AND deleted=0');
			$result = $query->execute();
		}
		else if(\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::isLoaded('news')){
			
			//if no tt_news get entries of newssystem
			if(!$result){
				$query->statement('SELECT uid, title, tstamp, crdate, datetime, teaser, bodytext FROM tx_news_domain_model_news WHERE hidden=0 AND deleted=0');
				$result = $query->execute();
			}
				
		}
		else{
			//no news
		}
		
		$newsItems = array();
		
		$i = 0;
		
		foreach($result as $news){
			
			if(!$this->newsInEyepin($news['uid'])){
			
				$newsItem['uid'] = $news['uid'];
				$newsItem['title'] = $news['title'];
				$newsItem['crdate'] = $news['crdate'];
				$newsItem['tstamp'] = $news['tstamp'];
				$newsItem['teaser'] = $news['teaser'];
				$newsItem['bodytext'] = $news['bodytext'];
				$newsItem['image'] = $news['image'];
				$newsItem['imagecaption'] = $news['imagecaption'];
				
				if($this->newsInEyepin($news['uid'])){
					$newsItem['eyepin'] = 1;
				}
				else{
					$newsItem['eyepin'] = 0;
				}
				
				$newsItems[$i] = $newsItem;
				$i++;
			}
		}
		
		return $newsItems;
	}
	
	/**
	 * check if news is in eyepin
	 * 
	 * @param string $newsId
	 * @return $result - eyepin-news data
	 */
	public function newsInEyepin($newsId){
		
		$query = $this -> createQuery();
		$query->getQuerySettings()->setReturnRawQueryResult(TRUE);
		
		$query->statement('SELECT uid, eyepinid, newsid FROM tx_eyepin6_domain_model_eyepin WHERE newsid=' . $newsId . ' ORDER by uid DESC LIMIT 1');
		
		$result = $query->execute();
		
		return $result;
		
	}
	
	/** 
	 * find article by id (tt_news or tx_news)
	 * 
	 * @param string $articleId
	 * @return $result - news data
	 */
	public function findArticleById($articleId){
		
		$query = $this -> createQuery();
		$query->getQuerySettings()->setReturnRawQueryResult(TRUE);
		
		if(\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::isLoaded('tt_news')){

			//get tt_news entries
			$query->statement('SELECT * FROM tt_news WHERE uid=' . $articleId);
			$result = $query->execute();
		}
		else if(\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::isLoaded('news')){
			
			//get news system entries
			$query->statement('SELECT * FROM tx_news_domain_model_news WHERE uid=' . $articleId);
			$result = $query->execute();
				
		}
		else{
			//no news
		}
		
		return $result;
		
	}
	
	/**
	 * find media for article
	 * 
	 * @param string $mediaId
	 */
	public function findArticleMediaById($mediaId){
		
		$query = $this -> createQuery();
		$query->getQuerySettings()->setReturnRawQueryResult(TRUE);
		
		if(\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::isLoaded('tt_news')){

			//get tt_news entries
		
			$db = $GLOBALS['TYPO3_DB'];

			$result = $db->exec_SELECTquery('tt_news', array('uid' => $mediaId));
			
		}
		else if(\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::isLoaded('news')){
			
			//get news system entries
			
			$db = $GLOBALS['TYPO3_DB'];

			$result = $db->exec_SELECTquery('tx_news_domain_model_media', array('uid' => $mediaId));
	
				
		}
		else{
			//no news
		}
		
		return $result;
		
	}
	
	/**
	 * add article to eyepin database table
	 * 
	 * @param  $newsItem
	 */
	public function add($newsItem){
		
		/* @var $db \TYPO3\CMS\Core\Database\DatabaseConnection */
		$db = $GLOBALS['TYPO3_DB'];

		$db->exec_INSERTquery('tx_eyepin6_domain_model_eyepin', array('eyepinid' => $newsItem->getEyepinid(), 'newsid' => $newsItem->getNewsid()));
	
		$persistenceManager = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance("TYPO3\\CMS\\Extbase\\Persistence\\Generic\\PersistenceManager");
		$persistenceManager->persistAll();

	}
	
	/** 
	 * remove article from eyepin database table
	 * 
	 * @param unknown_type $articleId
	 */
	public function deleteArticle($articleId){
	
		
		/* @var $db \TYPO3\CMS\Core\Database\DatabaseConnection */
		$db = $GLOBALS['TYPO3_DB'];
		
		$db->exec_DELETEquery('tx_eyepin6_domain_model_eyepin', 'newsid=' . $articleId);
	
		$persistenceManager = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance("TYPO3\\CMS\\Extbase\\Persistence\\Generic\\PersistenceManager");
		$persistenceManager->persistAll();
		
		echo("delete item from db");

	}
	
}
?>